@@ -15,8 +15,8 @@ from zeep.xsd.valueobjects import CompoundValue
 
 from . import constants, helpers, passport
 from .config import Config
-from .restlet import NetsuiteRestlet
 from .rest_api import NetSuiteRestApi
+from .restlet import NetsuiteRestlet
 from .util import cached_property
 
 logger = logging.getLogger(__name__)
@@ -27,10 +27,7 @@ class NetsuiteResponseError(Exception):
 
 
 def WebServiceCall(
-    path: str = None,
-    extract: Callable = None,
-    *,
-    default: Any = constants.NOT_SET,
+    path: str = None, extract: Callable = None, *, default: Any = constants.NOT_SET,
 ) -> Callable:
     """
     Decorator for NetSuite methods returning SOAP responses
@@ -47,13 +44,14 @@ def WebServiceCall(
     Returns:
         Decorator to use on `NetSuite` web service methods
     """
+
     def decorator(fn):
         @wraps(fn)
         def wrapper(self, *args, **kw):
             response = fn(self, *args, **kw)
 
             if path is not None:
-                for part in path.split('.'):
+                for part in path.split("."):
                     try:
                         response = getattr(response, part)
                     except AttributeError:
@@ -63,26 +61,28 @@ def WebServiceCall(
                             return default
 
             try:
-                response_status = response['status']
+                response_status = response["status"]
             except TypeError:
                 response_status = None
                 for record in response:
                     # NOTE: Status is set on each returned record for lists,
                     #       really strange...
-                    response_status = record['status']
+                    response_status = record["status"]
                     break
 
-            is_success = response_status['isSuccess']
+            is_success = response_status["isSuccess"]
 
             if not is_success:
-                response_detail = response_status['statusDetail']
+                response_detail = response_status["statusDetail"]
                 raise NetsuiteResponseError(response_detail)
 
             if extract is not None:
                 response = extract(response)
 
             return response
+
         return wrapper
+
     return decorator
 
 
@@ -103,7 +103,7 @@ class NetSuiteTransport(Transport):
         Assign the dynamic host domain component to a class variable
         """
         parsed_wsdl_url = urlparse(wsdl_url)
-        self._wsdl_url = f'{parsed_wsdl_url.scheme}://{parsed_wsdl_url.netloc}/'
+        self._wsdl_url = f"{parsed_wsdl_url.scheme}://{parsed_wsdl_url.netloc}/"
 
         super().__init__(**kwargs)
 
@@ -112,7 +112,7 @@ class NetSuiteTransport(Transport):
         Munge the address to the dynamic domain, not the default
         """
 
-        idx = address.index('/', 8) + 1
+        idx = address.index("/", 8) + 1
         address = self._wsdl_url + address[idx:]
         return address
 
@@ -130,11 +130,11 @@ class NetSuiteTransport(Transport):
 
 
 class NetSuite:
-    version = '2019.2.0'
-    wsdl_url_tmpl = 'https://{account_id}.suitetalk.api.netsuite.com/wsdl/v{underscored_version}/netsuite.wsdl'
+    version = "2019.2.0"
+    wsdl_url_tmpl = "https://{account_id}.suitetalk.api.netsuite.com/wsdl/v{underscored_version}/netsuite.wsdl"
 
     def __repr__(self) -> str:
-        return f'<NetSuite {self.hostname}({self.version})>'
+        return f"<NetSuite {self.hostname}({self.version})>"
 
     def __init__(
         self,
@@ -144,19 +144,19 @@ class NetSuite:
         wsdl_url: str = None,
         cache: zeep.cache.Base = None,
         session: requests.Session = None,
-        sandbox: bool = None
+        sandbox: bool = None,
     ) -> None:
 
         if sandbox is not None:
             warnings.warn(
-                'The `sandbox` flag has been deprecated and no longer has '
-                'any effect. Please locate the correct account ID for your '
-                'sandbox instead (usually `_SB1`)',
+                "The `sandbox` flag has been deprecated and no longer has "
+                "any effect. Please locate the correct account ID for your "
+                "sandbox instead (usually `_SB1`)",
                 DeprecationWarning,
             )
 
         if version is not None:
-            assert re.match(r'\d+\.\d+\.\d+', version)
+            assert re.match(r"\d+\.\d+\.\d+", version)
             self.version = version
 
         self.__config = self._make_config(config)
@@ -207,33 +207,30 @@ class NetSuite:
 
     @cached_property
     def hostname(self) -> str:
-        return self.wsdl_url.replace('https://', '').partition('/')[0]
+        return self.wsdl_url.replace("https://", "").partition("/")[0]
 
     @property
     def service(self) -> zeep.client.ServiceProxy:
         return self.client.service
 
-    def _make_config(
-        self,
-        values_obj: Dict
-    ) -> Config:
+    def _make_config(self, values_obj: Dict) -> Config:
         if isinstance(values_obj, Config):
             return values_obj
         return Config(**values_obj)
 
     @property
     def underscored_version(self) -> str:
-        return self.version.replace('.', '_')
+        return self.version.replace(".", "_")
 
     @property
     def underscored_version_no_micro(self) -> str:
-        return self.underscored_version.rpartition('_')[0]
+        return self.underscored_version.rpartition("_")[0]
 
     def _generate_wsdl_url(self) -> str:
         return self.wsdl_url_tmpl.format(
             underscored_version=self.underscored_version,
             # https://followingnetsuite.wordpress.com/2018/10/18/suitetalk-sandbox-urls-addendum/
-            account_id=self.config.account.lower().replace('_', '-'),
+            account_id=self.config.account.lower().replace("_", "-"),
         )
 
     def _generate_cache(self) -> zeep.cache.Base:
@@ -244,9 +241,7 @@ class NetSuite:
 
     def _generate_transport(self) -> zeep.transports.Transport:
         return NetSuiteTransport(
-            self._generate_wsdl_url(),
-            session=self.session,
-            cache=self.cache,
+            self._generate_wsdl_url(), session=self.session, cache=self.cache,
         )
 
     def generate_passport(self) -> Dict:
@@ -263,242 +258,223 @@ class NetSuite:
             yield
 
     @staticmethod
-    def _set_default_soapheaders(
-        client: zeep.Client,
-        preferences: dict = None
-    ) -> None:
-        client.set_default_soapheaders({
-            # https://netsuite.custhelp.com/app/answers/detail/a_id/40934
-            # (you need to be logged in to SuiteAnswers for this link to work)
-            # 'preferences': {
-            #     'warningAsError': True/False,
-            #     'disableMandatoryCustomFieldValidation': True/False,
-            #     'disableSystemNotesForCustomFields': True/False,
-            #     'ignoreReadOnlyFields': True/False,
-            #     'runServerSuiteScriptAndTriggerWorkflows': True/False,
-            # },
-        })
+    def _set_default_soapheaders(client: zeep.Client, preferences: dict = None) -> None:
+        client.set_default_soapheaders(
+            {
+                # https://netsuite.custhelp.com/app/answers/detail/a_id/40934
+                # (you need to be logged in to SuiteAnswers for this link to work)
+                # 'preferences': {
+                #     'warningAsError': True/False,
+                #     'disableMandatoryCustomFieldValidation': True/False,
+                #     'disableSystemNotesForCustomFields': True/False,
+                #     'ignoreReadOnlyFields': True/False,
+                #     'runServerSuiteScriptAndTriggerWorkflows': True/False,
+                # },
+            }
+        )
 
     def _generate_client(self) -> zeep.Client:
-        client = zeep.Client(
-            self.wsdl_url,
-            transport=self.transport,
-        )
+        client = zeep.Client(self.wsdl_url, transport=self.transport,)
         self._set_default_soapheaders(
-            client,
-            preferences=self.config.preferences,
+            client, preferences=self.config.preferences,
         )
         return client
 
     def _get_namespace(self, name: str, sub_namespace: str) -> str:
-        return (
-            'urn:{name}_{version}.{sub_namespace}.webservices.netsuite.com'
-            .format(
-                name=name,
-                version=self.underscored_version_no_micro,
-                sub_namespace=sub_namespace,
-            )
+        return "urn:{name}_{version}.{sub_namespace}.webservices.netsuite.com".format(
+            name=name,
+            version=self.underscored_version_no_micro,
+            sub_namespace=sub_namespace,
         )
 
-    def _type_factory(
-        self,
-        name: str,
-        sub_namespace: str
-    ) -> zeep.client.Factory:
-        return self.client.type_factory(
-            self._get_namespace(name, sub_namespace)
-        )
+    def _type_factory(self, name: str, sub_namespace: str) -> zeep.client.Factory:
+        return self.client.type_factory(self._get_namespace(name, sub_namespace))
 
     @cached_property
     def Core(self) -> zeep.client.Factory:
-        return self._type_factory('core', 'platform')
+        return self._type_factory("core", "platform")
 
     @cached_property
     def CoreTypes(self) -> zeep.client.Factory:
-        return self._type_factory('types.core', 'platform')
+        return self._type_factory("types.core", "platform")
 
     @cached_property
     def FaultsTypes(self) -> zeep.client.Factory:
-        return self._type_factory('types.faults', 'platform')
+        return self._type_factory("types.faults", "platform")
 
     @cached_property
     def Faults(self) -> zeep.client.Factory:
-        return self._type_factory('faults', 'platform')
+        return self._type_factory("faults", "platform")
 
     @cached_property
     def Messages(self) -> zeep.client.Factory:
-        return self._type_factory('messages', 'platform')
+        return self._type_factory("messages", "platform")
 
     @cached_property
     def Common(self) -> zeep.client.Factory:
-        return self._type_factory('common', 'platform')
+        return self._type_factory("common", "platform")
 
     @cached_property
     def CommonTypes(self) -> zeep.client.Factory:
-        return self._type_factory('types.common', 'platform')
+        return self._type_factory("types.common", "platform")
 
     @cached_property
     def Scheduling(self) -> zeep.client.Factory:
-        return self._type_factory('scheduling', 'activities')
+        return self._type_factory("scheduling", "activities")
 
     @cached_property
     def SchedulingTypes(self) -> zeep.client.Factory:
-        return self._type_factory('types.scheduling', 'activities')
+        return self._type_factory("types.scheduling", "activities")
 
     @cached_property
     def Communication(self) -> zeep.client.Factory:
-        return self._type_factory('communication', 'general')
+        return self._type_factory("communication", "general")
 
     @cached_property
     def CommunicationTypes(self) -> zeep.client.Factory:
-        return self._type_factory('types.communication', 'general')
+        return self._type_factory("types.communication", "general")
 
     @cached_property
     def Filecabinet(self) -> zeep.client.Factory:
-        return self._type_factory('filecabinet', 'documents')
+        return self._type_factory("filecabinet", "documents")
 
     @cached_property
     def FilecabinetTypes(self) -> zeep.client.Factory:
-        return self._type_factory('types.filecabinet', 'documents')
+        return self._type_factory("types.filecabinet", "documents")
 
     @cached_property
     def Relationships(self) -> zeep.client.Factory:
-        return self._type_factory('relationships', 'lists')
+        return self._type_factory("relationships", "lists")
 
     @cached_property
     def RelationshipsTypes(self) -> zeep.client.Factory:
-        return self._type_factory('types.relationships', 'lists')
+        return self._type_factory("types.relationships", "lists")
 
     @cached_property
     def Support(self) -> zeep.client.Factory:
-        return self._type_factory('support', 'lists')
+        return self._type_factory("support", "lists")
 
     @cached_property
     def SupportTypes(self) -> zeep.client.Factory:
-        return self._type_factory('types.support', 'lists')
+        return self._type_factory("types.support", "lists")
 
     @cached_property
     def Accounting(self) -> zeep.client.Factory:
-        return self._type_factory('accounting', 'lists')
+        return self._type_factory("accounting", "lists")
 
     @cached_property
     def AccountingTypes(self) -> zeep.client.Factory:
-        return self._type_factory('types.accounting', 'lists')
+        return self._type_factory("types.accounting", "lists")
 
     @cached_property
     def Sales(self) -> zeep.client.Factory:
-        return self._type_factory('sales', 'transactions')
+        return self._type_factory("sales", "transactions")
 
     @cached_property
     def SalesTypes(self) -> zeep.client.Factory:
-        return self._type_factory('types.sales', 'transactions')
+        return self._type_factory("types.sales", "transactions")
 
     @cached_property
     def Purchases(self) -> zeep.client.Factory:
-        return self._type_factory('purchases', 'transactions')
+        return self._type_factory("purchases", "transactions")
 
     @cached_property
     def PurchasesTypes(self) -> zeep.client.Factory:
-        return self._type_factory('types.purchases', 'transactions')
+        return self._type_factory("types.purchases", "transactions")
 
     @cached_property
     def Customers(self) -> zeep.client.Factory:
-        return self._type_factory('customers', 'transactions')
+        return self._type_factory("customers", "transactions")
 
     @cached_property
     def CustomersTypes(self) -> zeep.client.Factory:
-        return self._type_factory('types.customers', 'transactions')
+        return self._type_factory("types.customers", "transactions")
 
     @cached_property
     def Financial(self) -> zeep.client.Factory:
-        return self._type_factory('financial', 'transactions')
+        return self._type_factory("financial", "transactions")
 
     @cached_property
     def FinancialTypes(self) -> zeep.client.Factory:
-        return self._type_factory('types.financial', 'transactions')
+        return self._type_factory("types.financial", "transactions")
 
     @cached_property
     def Bank(self) -> zeep.client.Factory:
-        return self._type_factory('bank', 'transactions')
+        return self._type_factory("bank", "transactions")
 
     @cached_property
     def BankTypes(self) -> zeep.client.Factory:
-        return self._type_factory('types.bank', 'transactions')
+        return self._type_factory("types.bank", "transactions")
 
     @cached_property
     def Inventory(self) -> zeep.client.Factory:
-        return self._type_factory('inventory', 'transactions')
+        return self._type_factory("inventory", "transactions")
 
     @cached_property
     def InventoryTypes(self) -> zeep.client.Factory:
-        return self._type_factory('types.inventory', 'transactions')
+        return self._type_factory("types.inventory", "transactions")
 
     @cached_property
     def General(self) -> zeep.client.Factory:
-        return self._type_factory('general', 'transactions')
+        return self._type_factory("general", "transactions")
 
     @cached_property
     def Customization(self) -> zeep.client.Factory:
-        return self._type_factory('customization', 'setup')
+        return self._type_factory("customization", "setup")
 
     @cached_property
     def CustomizationTypes(self) -> zeep.client.Factory:
-        return self._type_factory('types.customization', 'setup')
+        return self._type_factory("types.customization", "setup")
 
     @cached_property
     def Employees(self) -> zeep.client.Factory:
-        return self._type_factory('employees', 'lists')
+        return self._type_factory("employees", "lists")
 
     @cached_property
     def EmployeesTypes(self) -> zeep.client.Factory:
-        return self._type_factory('types.employees', 'lists')
+        return self._type_factory("types.employees", "lists")
 
     @cached_property
     def Website(self) -> zeep.client.Factory:
-        return self._type_factory('website', 'lists')
+        return self._type_factory("website", "lists")
 
     @cached_property
     def WebsiteTypes(self) -> zeep.client.Factory:
-        return self._type_factory('types.website', 'lists')
+        return self._type_factory("types.website", "lists")
 
     @cached_property
     def EmployeesTransactions(self) -> zeep.client.Factory:
-        return self._type_factory('employees', 'transactions')
+        return self._type_factory("employees", "transactions")
 
     @cached_property
     def EmployeesTransactionsTypes(self) -> zeep.client.Factory:
-        return self._type_factory('types.employees', 'transactions')
+        return self._type_factory("types.employees", "transactions")
 
     @cached_property
     def Marketing(self) -> zeep.client.Factory:
-        return self._type_factory('marketing', 'lists')
+        return self._type_factory("marketing", "lists")
 
     @cached_property
     def MarketingTypes(self) -> zeep.client.Factory:
-        return self._type_factory('types.marketing', 'lists')
+        return self._type_factory("types.marketing", "lists")
 
     @cached_property
     def DemandPlanning(self) -> zeep.client.Factory:
-        return self._type_factory('demandplanning', 'transactions')
+        return self._type_factory("demandplanning", "transactions")
 
     @cached_property
     def DemandPlanningTypes(self) -> zeep.client.Factory:
-        return self._type_factory('types.demandplanning', 'transactions')
+        return self._type_factory("types.demandplanning", "transactions")
 
     @cached_property
     def SupplyChain(self) -> zeep.client.Factory:
-        return self._type_factory('supplychain', 'lists')
+        return self._type_factory("supplychain", "lists")
 
     @cached_property
     def SupplyChainTypes(self) -> zeep.client.Factory:
-        return self._type_factory('types.supplychain', 'lists')
+        return self._type_factory("types.supplychain", "lists")
 
-    def request(
-        self,
-        service_name: str,
-        *args,
-        **kw
-    ) -> zeep.xsd.ComplexType:
+    def request(self, service_name: str, *args, **kw) -> zeep.xsd.ComplexType:
         """
         Make a web service request to NetSuite
 
@@ -512,146 +488,128 @@ class NetSuite:
         return svc(*args, _soapheaders=self.generate_passport(), **kw)
 
     @WebServiceCall(
-        'body.readResponseList.readResponse',
-        extract=lambda resp: [r['record'] for r in resp]
+        "body.readResponseList.readResponse",
+        extract=lambda resp: [r["record"] for r in resp],
     )
     def getList(
         self,
         recordType: str,
         *,
         internalIds: Sequence[int] = (),
-        externalIds: Sequence[str] = ()
+        externalIds: Sequence[str] = (),
     ) -> List[CompoundValue]:
         """Get a list of records"""
 
         if len(list(internalIds) + list(externalIds)) == 0:
-            raise ValueError('Please specify `internalId` and/or `externalId`')
+            raise ValueError("Please specify `internalId` and/or `externalId`")
 
         return self.request(
-            'getList',
+            "getList",
             self.Messages.GetListRequest(
                 baseRef=[
-                    self.Core.RecordRef(
-                        type=recordType,
-                        internalId=internalId,
-                    ) for internalId in internalIds
-                ] + [
-                    self.Core.RecordRef(
-                        type=recordType,
-                        externalId=externalId,
-                    ) for externalId in externalIds
+                    self.Core.RecordRef(type=recordType, internalId=internalId,)
+                    for internalId in internalIds
+                ]
+                + [
+                    self.Core.RecordRef(type=recordType, externalId=externalId,)
+                    for externalId in externalIds
                 ],
-            )
-        )
-
-    @WebServiceCall(
-        'body.readResponse',
-        extract=lambda resp: resp['record'],
-    )
-    def get(
-        self,
-        recordType: str,
-        *,
-        internalId: int = None,
-        externalId: str = None
-    ) -> CompoundValue:
-        """Get a single record"""
-        if len([v for v in (internalId, externalId) if v is not None]) != 1:
-            raise ValueError('Specify either `internalId` or `externalId`')
-
-        if internalId:
-            record_ref = self.Core.RecordRef(
-                type=recordType,
-                internalId=internalId,
-            )
-        else:
-            self.Core.RecordRef(
-                type=recordType,
-                externalId=externalId,
-            )
-
-        return self.request('get', baseRef=record_ref)
-
-    @WebServiceCall(
-        'body.getAllResult',
-        extract=lambda resp: resp['recordList']['record'],
-    )
-    def getAll(self, recordType: str) -> List[CompoundValue]:
-        """Get all records of a given type."""
-        return self.request(
-            'getAll',
-            record=self.Core.GetAllRecord(
-                recordType=recordType,
             ),
         )
 
     @WebServiceCall(
-        'body.writeResponse',
-        extract=lambda resp: resp['baseRef'],
+        "body.readResponse", extract=lambda resp: resp["record"],
+    )
+    def get(
+        self, recordType: str, *, internalId: int = None, externalId: str = None
+    ) -> CompoundValue:
+        """Get a single record"""
+        if len([v for v in (internalId, externalId) if v is not None]) != 1:
+            raise ValueError("Specify either `internalId` or `externalId`")
+
+        if internalId:
+            record_ref = self.Core.RecordRef(type=recordType, internalId=internalId,)
+        else:
+            self.Core.RecordRef(
+                type=recordType, externalId=externalId,
+            )
+
+        return self.request("get", baseRef=record_ref)
+
+    @WebServiceCall(
+        "body.getAllResult", extract=lambda resp: resp["recordList"]["record"],
+    )
+    def getAll(self, recordType: str) -> List[CompoundValue]:
+        """Get all records of a given type."""
+        return self.request(
+            "getAll", record=self.Core.GetAllRecord(recordType=recordType,),
+        )
+
+    @WebServiceCall(
+        "body.writeResponse", extract=lambda resp: resp["baseRef"],
     )
     def add(self, record: CompoundValue) -> CompoundValue:
         """Insert a single record."""
-        return self.request('add', record=record)
+        return self.request("add", record=record)
 
     @WebServiceCall(
-        'body.writeResponse',
-        extract=lambda resp: resp['baseRef'],
+        "body.writeResponse", extract=lambda resp: resp["baseRef"],
     )
     def update(self, record: CompoundValue) -> CompoundValue:
         """Insert a single record."""
-        return self.request('update', record=record)
+        return self.request("update", record=record)
 
     @WebServiceCall(
-        'body.writeResponse',
-        extract=lambda resp: resp['baseRef'],
+        "body.writeResponse", extract=lambda resp: resp["baseRef"],
     )
     def upsert(self, record: CompoundValue) -> CompoundValue:
         """Upsert a single record."""
-        return self.request('upsert', record=record)
+        return self.request("upsert", record=record)
 
     @WebServiceCall(
-        'body.searchResult',
-        extract=lambda resp: resp['recordList']['record'],
+        "body.searchResult", extract=lambda resp: resp["recordList"]["record"],
     )
     def search(self, record: CompoundValue) -> List[CompoundValue]:
         """Search records"""
-        return self.request('search', searchRecord=record)
+        return self.request("search", searchRecord=record)
 
     @WebServiceCall(
-        'body.writeResponseList',
-        extract=lambda resp: [record['baseRef'] for record in resp],
+        "body.writeResponseList",
+        extract=lambda resp: [record["baseRef"] for record in resp],
     )
     def upsertList(self, records: List[CompoundValue]) -> List[CompoundValue]:
         """Upsert a list of records."""
-        return self.request('upsertList', record=records)
+        return self.request("upsertList", record=records)
 
     @WebServiceCall(
-        'body.getItemAvailabilityResult',
-        extract=lambda resp: resp['itemAvailabilityList']['itemAvailability'],
-        default=[]
+        "body.getItemAvailabilityResult",
+        extract=lambda resp: resp["itemAvailabilityList"]["itemAvailability"],
+        default=[],
     )
     def getItemAvailability(
         self,
         *,
         internalIds: Sequence[int] = (),
         externalIds: Sequence[str] = (),
-        lastQtyAvailableChange: datetime = None
+        lastQtyAvailableChange: datetime = None,
     ) -> List[Dict]:
         if len(list(internalIds) + list(externalIds)) == 0:
-            raise ValueError('Please specify `internalId` and/or `externalId`')
+            raise ValueError("Please specify `internalId` and/or `externalId`")
 
         item_filters = [
-            {'type': 'inventoryItem', 'internalId': internalId}
+            {"type": "inventoryItem", "internalId": internalId}
             for internalId in internalIds
         ] + [
-            {'type': 'inventoryItem', 'externalId': externalId}
+            {"type": "inventoryItem", "externalId": externalId}
             for externalId in externalIds
         ]
 
         return self.request(
-            'getItemAvailability',
-            itemAvailabilityFilter=[{
-                'item': {'recordRef': item_filters},
-                'lastQtyAvailableChange': lastQtyAvailableChange
-            }],
+            "getItemAvailability",
+            itemAvailabilityFilter=[
+                {
+                    "item": {"recordRef": item_filters},
+                    "lastQtyAvailableChange": lastQtyAvailableChange,
+                }
+            ],
         )
